Scatter plot display module UI
mod_plot_ui.RdRenders a bslib::card containing a plotly scatter plot and a movie count.
Value
A bslib::card.
mod_plot_ui.RdRenders a bslib::card containing a plotly scatter plot and a movie count.
A bslib::card.